@@ -118,8 +118,10 @@ static int naco_img_lampflat(cpl_frameset            * framelist,
     /* Retrieve input parameters */
     rej_bord = naco_parameterlist_get_string(parlist, RECIPE_STRING, NACO_PARAM_REJBORD);
     skip_if (0);
-    skip_if (sscanf(rej_bord, "%d %d %d %d",
-                    &rej_left, &rej_right, &rej_bottom, &rej_top) != 4);
+    skip_if_ne(sscanf(rej_bord, "%d %d %d %d",
+                      &rej_left, &rej_right, &rej_bottom, &rej_top), 4,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_REJBORD), rej_bord);
   
     /* Identify the RAW and CALIB frames in the input frameset */
     skip_if (naco_dfs_set_groups(framelist));
