@@ -382,10 +382,11 @@ static cpl_boolean naco_util_img_std_set_row(cpl_table * self,
 {
 
     /* gcc can only check sscanf()s format when it is a string literal */
-#define FORMAT "%s %lg %lg %s %lg %lg %lg %lg %lg %lg %lg %lg"
+#define FORMAT "%" CPL_STRINGIFY(NACO_ASCII_MAXLINELEN) "s %lg %lg %"   \
+        CPL_STRINGIFY(NACO_ASCII_MAXLINELEN) "s %lg %lg %lg %lg %lg %lg %lg %lg"
 
-    char         sname[NACO_ASCII_MAXLINELEN];
-    char         stype[NACO_ASCII_MAXLINELEN];
+    char         sname[NACO_ASCII_MAXLINELEN + 1];
+    char         stype[NACO_ASCII_MAXLINELEN + 1];
     double       mags[NFILTERS];
     double       ra, dec;
     int          nvals;
